# -*- coding: utf-8 -*-
##############################################################################
# This file is part of the "use_control" OpenERP module.
# See LICENCE file at the root of the module folder.
##############################################################################

from osv import fields,osv


# TODO use group_by searchs instead of sql views

class use_control_time(osv.osv):
    _name = "use.control.time"
    _order = "date desc"
    _rec_name = 'date'
    _columns = {
        'user_id': fields.many2one('res.users', 'User', ondelete='set null'),
        'date': fields.datetime('Date'),
        'duration': fields.float('Duration'),
        'uploaded': fields.boolean('Uploaded'),
        'active': fields.boolean('Active'), # inactive lines are old ones, before a migration, i.e.
    }
    _defaults = {
        'active': lambda *a: True,
        'uploaded': lambda *a: False,
    }

    def write(self, cr, uid, ids, data, context={}):
        return True
    def unlink(self, cr, uid, ids, context={}):
        return True
use_control_time()

class use_control_time_month_user(osv.osv):
    _name = "use.control.time.month.user"
    _description = "Time of Use per Month"
    _auto = False
    _rec_name = 'date'
    _columns = {
        'user_id': fields.many2one('res.users', 'User', ondelete='set null'),
        'date': fields.date('Month'),
        'duration': fields.float('Duration'),
    }
    def init(self, cr):
        cr.execute("""
            create or replace view use_control_time_month_user as (
                select
                    min(id) as id,
                    user_id,
                    to_char(date, 'YYYY-MM-01') as date,
                    sum(duration) as duration
                from
                    use_control_time
                WHERE active = %s
                group by
                    user_id,
                    to_char(date, 'YYYY-MM-01')
            )""", (True,))
use_control_time_month_user()


class use_control_time_month(osv.osv):
    _name = "use.control.time.month"
    _description = "Time of Use per Month"
    _auto = False
    _rec_name = 'date'
    _columns = {
        'date': fields.date('Month'),
        'duration': fields.float('Duration'),
    }
    def init(self, cr):
        cr.execute("""
            create or replace view use_control_time_month as (
                select
                    min(id) as id,
                    to_char(date, 'YYYY-MM-01') as date,
                    sum(duration) as duration
                from
                    use_control_time
                WHERE active = %s
                group by
                    to_char(date, 'YYYY-MM-01')
            )""", (True,))
use_control_time_month()

class use_control_db_block(osv.osv):
    _name = "use.control.db.block"
    _description = "Containt the blocking message"

    _columns = {
        'name': fields.text('Block message', required=True),
    }

    def create(self, cr, uid, values, context=None):
        self.unlink(cr, uid, self.search(cr, uid, [], context), context)
        return super(use_control_db_block, self).create(cr, uid, values, context)

    def copy(self, cr, uid, id, context):
        return id

use_control_db_block()

